# coding: utf-8

"""
    FreeClimb API

    No description provided (generated by Openapi Generator https://github.com/openapitools/openapi-generator)  # noqa: E501

    The version of the OpenAPI document: 0.0.1
    Generated by: https://openapi-generator.tech
"""


from __future__ import absolute_import

import unittest

import freeclimb
from freeclimb.models.application_list import ApplicationList  # noqa: E501
from freeclimb.models.application_result import ApplicationResult
from freeclimb.rest import ApiException


class TestApplicationList(unittest.TestCase):
    """ApplicationList unit test stubs"""

    def setUp(self):
        self.application1 = ApplicationResult('http://localhost:80/application1')
        self.application2 = ApplicationResult('http://localhost:80/application2')
        self.application_list = ApplicationList(next_page_uri='http://localhost:80/2', applications=[self.application1, self.application2])

    def tearDown(self):
        pass

    def testApplicationList(self):
        """Test ApplicationList"""
        # construct object with mandatory attributes with example values
        # model = freeclimb.models.application_list.ApplicationList()  # noqa: E501
        self.assertTrue(isinstance(self.application_list, ApplicationList))


if __name__ == '__main__':
    unittest.main()
