# coding: utf-8

"""
    FreeClimb API

    No description provided (generated by Openapi Generator https://github.com/openapitools/openapi-generator)  # noqa: E501

    The version of the OpenAPI document: 0.0.1
    Generated by: https://openapi-generator.tech
"""


from __future__ import absolute_import

import unittest

import freeclimb
from freeclimb.models.call_result import CallResult  # noqa: E501
from freeclimb.rest import ApiException


class TestCallResult(unittest.TestCase):
    """CallResult unit test stubs"""

    def setUp(self):
        self.call_result = CallResult()

    def tearDown(self):
        pass

    def testCallResult(self):
        """Test CallResult"""
        # construct object with mandatory attributes with example values
        # model = freeclimb.models.call_result.CallResult()  # noqa: E501
        self.assertTrue(isinstance(self.call_result, CallResult))


if __name__ == '__main__':
    unittest.main()
