# coding: utf-8

"""
    FreeClimb API

    FreeClimb is a cloud-based application programming interface (API) that puts the power of the Vail platform in your hands. FreeClimb simplifies the process of creating applications that can use a full range of telephony features without requiring specialized or on-site telephony equipment. Using the FreeClimb REST API to write applications is easy! You have the option to use the language of your choice or hit the API directly. Your application can execute a command by issuing a RESTful request to the FreeClimb API. The base URL to send HTTP requests to the FreeClimb REST API is: /apiserver. FreeClimb authenticates and processes your request.  # noqa: E501

    The version of the OpenAPI document: 1.0.0
    Contact: support@freeclimb.com
    Generated by: https://openapi-generator.tech
"""


import pprint
import re  # noqa: F401

import six

from freeclimb.configuration import Configuration


class UpdateConferenceRequest(object):
    """NOTE: This class is auto generated by OpenAPI Generator.
    Ref: https://openapi-generator.tech

    Do not edit the class manually.
    """

    """
    Attributes:
      openapi_types (dict): The key is attribute name
                            and the value is attribute type.
      attribute_map (dict): The key is attribute name
                            and the value is json key in definition.
    """
    openapi_types = {
        'alias': 'str',
        'play_beep': 'str',
        'status': 'str',
        'request_id': 'str'
    }

    attribute_map = {
        'alias': 'alias',
        'play_beep': 'playBeep',
        'status': 'status',
        'request_id': 'requestId'
    }

    def __init__(self, alias=None, play_beep='always', status=None, request_id=None, local_vars_configuration=None):  # noqa: E501
        """UpdateConferenceRequest - a model defined in OpenAPI"""  # noqa: E501
        if local_vars_configuration is None:
            local_vars_configuration = Configuration()
        self.local_vars_configuration = local_vars_configuration

        self._alias = None
        self._play_beep = None
        self._status = None
        self._request_id = None
        self.discriminator = None

        if alias is not None:
            self.alias = alias
        if play_beep is not None:
            self.play_beep = play_beep
        if status is not None:
            self.status = status
        if request_id is not None:
            self.request_id = request_id

    @property
    def alias(self):
        """Gets the alias of this UpdateConferenceRequest.  # noqa: E501

        Description for this conference. Maximum 64 characters.  # noqa: E501

        :return: The alias of this UpdateConferenceRequest.  # noqa: E501
        :rtype: str
        """
        return self._alias

    @alias.setter
    def alias(self, alias):
        """Sets the alias of this UpdateConferenceRequest.

        Description for this conference. Maximum 64 characters.  # noqa: E501

        :param alias: The alias of this UpdateConferenceRequest.  # noqa: E501
        :type: str
        """

        self._alias = alias

    @property
    def play_beep(self):
        """Gets the play_beep of this UpdateConferenceRequest.  # noqa: E501

        Controls when a beep is played. Valid values: `always`, `never`, `entryOnly`, `exitOnly`.  # noqa: E501

        :return: The play_beep of this UpdateConferenceRequest.  # noqa: E501
        :rtype: str
        """
        return self._play_beep

    @play_beep.setter
    def play_beep(self, play_beep):
        """Sets the play_beep of this UpdateConferenceRequest.

        Controls when a beep is played. Valid values: `always`, `never`, `entryOnly`, `exitOnly`.  # noqa: E501

        :param play_beep: The play_beep of this UpdateConferenceRequest.  # noqa: E501
        :type: str
        """

        self._play_beep = play_beep

    @property
    def status(self):
        """Gets the status of this UpdateConferenceRequest.  # noqa: E501

        New status of the conference. Valid values: `empty` or `terminated`. For more information, see **Status Parameter** below.**  # noqa: E501

        :return: The status of this UpdateConferenceRequest.  # noqa: E501
        :rtype: str
        """
        return self._status

    @status.setter
    def status(self, status):
        """Sets the status of this UpdateConferenceRequest.

        New status of the conference. Valid values: `empty` or `terminated`. For more information, see **Status Parameter** below.**  # noqa: E501

        :param status: The status of this UpdateConferenceRequest.  # noqa: E501
        :type: str
        """
        allowed_values = ["empty", "terminated"]  # noqa: E501
        if self.local_vars_configuration.client_side_validation and status not in allowed_values:  # noqa: E501
            raise ValueError(
                "Invalid value for `status` ({0}), must be one of {1}"  # noqa: E501
                .format(status, allowed_values)
            )

        self._status = status

    @property
    def request_id(self):
        """Gets the request_id of this UpdateConferenceRequest.  # noqa: E501

        ID for this request starting with prefix *RQ* followed by 40 hexadecimal characters. FreeClimb logs generated while processing this request will include this requestId. If it is not provided, FreeClimb will generate a requestId and return it as a header in the response (e.g. X-Pulse-Request-Id: <requestId>).  # noqa: E501

        :return: The request_id of this UpdateConferenceRequest.  # noqa: E501
        :rtype: str
        """
        return self._request_id

    @request_id.setter
    def request_id(self, request_id):
        """Sets the request_id of this UpdateConferenceRequest.

        ID for this request starting with prefix *RQ* followed by 40 hexadecimal characters. FreeClimb logs generated while processing this request will include this requestId. If it is not provided, FreeClimb will generate a requestId and return it as a header in the response (e.g. X-Pulse-Request-Id: <requestId>).  # noqa: E501

        :param request_id: The request_id of this UpdateConferenceRequest.  # noqa: E501
        :type: str
        """

        self._request_id = request_id

    def to_dict(self):
        """Returns the model properties as a dict"""
        result = {}

        for attr, _ in six.iteritems(self.openapi_types):
            value = getattr(self, attr)
            attr = self.to_camel_case(attr)
            if isinstance(value, list):
                result[attr] = list(map(
                    lambda x: x.to_dict() if hasattr(x, "to_dict") else x,
                    value
                ))
            elif hasattr(value, "to_dict"):
                result[attr] = value.to_dict()
            elif isinstance(value, dict):
                result[attr] = dict(map(
                    lambda item: (item[0], item[1].to_dict())
                    if hasattr(item[1], "to_dict") else item,
                    value.items()
                ))
            elif value is None:
                continue
            else:
                result[attr] = value

        return result

    def to_str(self):
        """Returns the string representation of the model"""
        return pprint.pformat(self.to_dict())

    def __repr__(self):
        """For `print` and `pprint`"""
        return self.to_str()

    def __eq__(self, other):
        """Returns true if both objects are equal"""
        if not isinstance(other, UpdateConferenceRequest):
            return False

        return self.to_dict() == other.to_dict()

    def __ne__(self, other):
        """Returns true if both objects are not equal"""
        if not isinstance(other, UpdateConferenceRequest):
            return True

        return self.to_dict() != other.to_dict()

    def to_camel_case(self, snake_str):
        components = snake_str.split('_')
        return components[0] + ''.join(x.title() for x in components[1:])
